@@ -26,6 +26,9 @@ typedef enum {
 
 	/** Remote supports fetching an individual reachable object. */
 	GIT_REMOTE_CAPABILITY_REACHABLE_OID = (1 << 1),
+
+	/** Remote supports push options. */
+	GIT_REMOTE_CAPABILITY_PUSH_OPTIONS = (1 << 2),
 } git_remote_capability_t;
 
 /**
